```
INSTALLATION

    $ pip3 install pypido

HELP

    $ pypido -h

USAGE

    $ pypido [-h] [-H] [-V] [-v] [-n] [-e] [-d] [-p] [-c] [-m] [-l]

              [package ...]

pypido - simple tool to create and publish Pypi packages (version 0.0.1 = not yet implemented!!!)

POSITIONAL ARGUMENTS

  package           package(s) to process

OPTIONAL ARGUMENTS

  -h, --help        show this help message and exit
  -H, --user-guide  open User Guide in PDF format and exit
  -V, --version     show program's version number and exit
  -v, --verbose     show what happens
  -n, --new         package # create a new unexisting package
  -e, --edit        package # edit an existing package
  -d, --delete      package # delete (i.e. remove) an existing package
  -p, --publish     package # publish an existing package
  -c, --copy        package package2 # copy an existing package into
                    unexisting package2
  -m, --move        package package2 # move (i.e. rename) an existing package
                    into unexisting package2
  -l, --list        # list all existing packages, published or not
```
